@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2020,2022,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -25,26 +25,33 @@
 #include <mes/config.h>
 #endif
 
-// CONSTANT STDIN 0
 #ifndef STDIN
 #define STDIN 0
 #endif
 
-// CONSTANT STDOUT 1
 #ifndef STDOUT
 #define STDOUT 1
 #endif
 
-// CONSTANT STDERR 2
 #ifndef STDERR
 #define STDERR 2
 #endif
 
+/* M2-Planet does not support pointer arithmetic.  Explicitly compensate
+   for that by multiplying with M2_PTR_SIZE when using (char)
+   pointers. */
+#if __M2__
+#define M2_PTR_SIZE sizeof (void*)
+#else
+#define M2_PTR_SIZE 1
+#endif
+
 extern char **environ;
 extern int __stdin;
 extern int __stdout;
 extern int __stderr;
 
+void __init_io ();
 int eputs (char const *s);
 int puts (char const *s);
 int oputs (char const *s);
@@ -63,10 +70,14 @@ int oputs (char const *s);
 #ifndef __MES_SIZE_T
 #define __MES_SIZE_T
 #undef size_t
+#if __M2__
+typedef unsigned size_t;
+#else
 typedef unsigned long size_t;
 #endif
 #endif
 #endif
+#endif
 
 #ifndef _SSIZE_T
 #define _SSIZE_T
