@@ -26,7 +26,7 @@
 int
 sigprocmask (int how, sigset_t const *set, sigset_t * oldset)
 {
-#if __i386__
+#if SYS_sigprocmask
   return _sys_call3 (SYS_sigprocmask, (long) how, (long) set, (long) oldset);
 #else
   return _sys_call3 (SYS_rt_sigprocmask, (long) how, (long) set, (long) oldset);
