@@ -23,6 +23,7 @@
 int
 fdputc (int c, int fd)
 {
-  write (fd, (char *) &c, 1);
+  char *p = cast_intp_to_charp (&c);
+  write (fd, p, 1);
   return 0;
 }
