@@ -19,12 +19,10 @@
  */
 
 #include <mes/lib.h>
-#include <assert.h>
 
 int
 fdungetc (int c, int fd)
 {
-  __ungetc_init ();
   if (c == -1)
     return c;
   else if (__ungetc_p (fd))
@@ -32,7 +30,7 @@ fdungetc (int c, int fd)
       eputs (" ***MES C LIB*** fdungetc ungetc buffer overflow fd=");
       eputs (itoa (fd));
       eputs ("\n");
-      assert (0);
+      assert_msg (0, "0");
     }
   __ungetc_set (fd, c);
   return c;
