@@ -80,6 +80,7 @@ gcc -g -D HAVE_CONFIG_H=1                       \
     src/string.c                                \
     src/struct.c                                \
     src/symbol.c                                \
+    src/variable.c                              \
     src/vector.c
 
 ## Check ##
@@ -94,7 +95,7 @@ echo '(display "hello\n")' | MES_BOOT=boot-01.scm out-system-libc/mes
 MES_DEBUG=4 MES=out-system-libc/mes tests/base.test
 
 # GC test
-MES_DEBUG=3 MES_ARENA=10000 MES_MAX_ARENA=10000 MES_BOOT=tests/gc.test out-system-libc/mes
+MES_DEBUG=3 MES_ARENA=20000 MES_MAX_ARENA=20000 MES_BOOT=tests/gc.test out-system-libc/mes
 
 # MesCC test
 # Interesting, but compiling multiple C files is not supported (yet).
@@ -211,6 +212,9 @@ $CC -g -D HAVE_CONFIG_H=1                               \
     lib/ctype/isnumber.c                                \
     lib/ctype/isspace.c                                 \
     lib/ctype/isxdigit.c                                \
+    lib/dirent/__getdirentries.c                        \
+    lib/dirent/opendir.c                                \
+    lib/dirent/closedir.c                               \
                                                         \
     lib/stub/__raise.c                                  \
     lib/mes/__assert_fail.c                             \
@@ -232,8 +236,11 @@ $CC -g -D HAVE_CONFIG_H=1                               \
     lib/stdio/putc.c                                    \
     lib/stdio/putchar.c                                 \
     lib/stdio/ungetc.c                                  \
+    lib/stdlib/calloc.c                                 \
     lib/stdlib/free.c                                   \
+    lib/linux/getpid.c                                  \
     lib/linux/malloc.c                                  \
+    lib/linux/pipe.c                                    \
     lib/stdlib/realloc.c                                \
     lib/string/memchr.c                                 \
     lib/string/memcmp.c                                 \
@@ -248,21 +255,38 @@ $CC -g -D HAVE_CONFIG_H=1                               \
                                                         \
     lib/linux/access.c                                  \
     lib/linux/brk.c                                     \
+    lib/linux/chdir.c                                   \
     lib/linux/chmod.c                                   \
     lib/linux/clock_gettime.c                           \
+    lib/linux/close.c                                   \
     lib/linux/dup.c                                     \
     lib/linux/dup2.c                                    \
     lib/linux/execve.c                                  \
+    lib/linux/fcntl.c                                   \
     lib/linux/fork.c                                    \
+    lib/linux/fstat.c                                   \
     lib/linux/fsync.c                                   \
     lib/linux/_getcwd.c                                 \
+    lib/linux/getdents.c                                \
     lib/linux/gettimeofday.c                            \
     lib/linux/ioctl3.c                                  \
+    lib/linux/link.c                                    \
+    lib/linux/lstat.c                                   \
+    lib/linux/mkdir.c                                   \
+    lib/linux/nanosleep.c                               \
     lib/linux/_open3.c                                  \
     lib/linux/read.c                                    \
     lib/linux/_read.c                                   \
+    lib/linux/readdir.c                                 \
+    lib/linux/rename.c                                  \
+    lib/linux/rmdir.c                                   \
+    lib/linux/stat.c                                    \
+    lib/linux/symlink.c                                 \
     lib/linux/time.c                                    \
+    lib/linux/umask.c                                   \
+    lib/linux/uname.c                                   \
     lib/linux/unlink.c                                  \
+    lib/linux/utimensat.c                               \
     include/sys/resource.h                              \
     lib/linux/wait4.c                                   \
     lib/linux/waitpid.c                                 \
@@ -286,6 +310,7 @@ $CC -g -D HAVE_CONFIG_H=1                               \
     src/string.c                                        \
     src/struct.c                                        \
     src/symbol.c                                        \
+    src/variable.c                                      \
     src/vector.c
 
 ## Check ##
@@ -300,7 +325,7 @@ echo '(display "hello\n")' | MES_BOOT=boot-01.scm out-mes/mes
 MES_DEBUG=4 MES=out-mes/mes tests/base.test
 
 # GC test
-MES_DEBUG=3 MES_ARENA=10000 MES_MAX_ARENA=10000 MES_BOOT=tests/gc.test out-mes/mes
+MES_DEBUG=3 MES_ARENA=20000 MES_MAX_ARENA=20000 MES_BOOT=tests/gc.test out-mes/mes
 
 # MesCC test
 # Interesting, but compiling multiple C files is not supported (yet).
